# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: powerpay_protos/device.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'powerpay_protos/device.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from powerpay_protos import integration_pb2 as powerpay__protos_dot_integration__pb2
from powerpay_protos import measurement_pb2 as powerpay__protos_dot_measurement__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cpowerpay_protos/device.proto\x12\x0fpowerpay.device\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a!powerpay_protos/integration.proto\x1a!powerpay_protos/measurement.proto\"\x8c\x01\n\x06\x44\x65vice\x12\x11\n\tnative_id\x18\x01 \x01(\t\x12?\n\x10integration_type\x18\x02 \x01(\x0e\x32%.powerpay.integration.IntegrationType\x12\x14\n\x0coutlet_index\x18\x03 \x01(\x05\x12\x18\n\x10integration_name\x18\x04 \x01(\t\"\xc6\x01\n\rDeviceRequest\x12\x36\n\x0bintegration\x18\x01 \x01(\x0b\x32!.powerpay.integration.Integration\x12\x11\n\tnative_id\x18\x02 \x01(\t\x12\x14\n\x0coutlet_index\x18\x03 \x01(\x05\x12\'\n\x06\x63onfig\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12+\n\nproperties\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\"|\n\x0e\x44\x65viceResponse\x12\'\n\x06\x64\x65vice\x18\x01 \x01(\x0b\x32\x17.powerpay.device.Device\x12\x30\n\x06status\x18\x02 \x01(\x0e\x32 .powerpay.device.OperationStatus\x12\x0f\n\x07message\x18\x03 \x01(\t\"u\n\x14\x44\x65viceControlCommand\x12\x30\n\x04type\x18\x01 \x01(\x0e\x32\".powerpay.device.DeviceControlType\x12+\n\nproperties\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\"~\n\x14\x44\x65viceControlRequest\x12.\n\x06\x64\x65vice\x18\x01 \x01(\x0b\x32\x1e.powerpay.device.DeviceRequest\x12\x36\n\x07\x63ommand\x18\x02 \x01(\x0b\x32%.powerpay.device.DeviceControlCommand\"[\n\x13\x43reateDeviceRequest\x12.\n\x06\x64\x65vice\x18\x01 \x01(\x0b\x32\x1e.powerpay.device.DeviceRequest\x12\x14\n\x0coutlet_count\x18\x02 \x01(\x05\"E\n\x13UpdateDeviceRequest\x12.\n\x06\x64\x65vice\x18\x01 \x01(\x0b\x32\x1e.powerpay.device.DeviceRequest\"E\n\x13\x44\x65leteDeviceRequest\x12.\n\x06\x64\x65vice\x18\x01 \x01(\x0b\x32\x1e.powerpay.device.DeviceRequest\"E\n\x13\x44\x65viceStatusRequest\x12.\n\x06\x64\x65vice\x18\x01 \x01(\x0b\x32\x1e.powerpay.device.DeviceRequest\"\x9a\x01\n\x14\x44\x65viceStatusResponse\x12\'\n\x06\x64\x65vice\x18\x01 \x01(\x0b\x32\x17.powerpay.device.Device\x12*\n\x05state\x18\x02 \x01(\x0b\x32\x1b.powerpay.measurement.State\x12-\n\tlast_seen\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp*\x87\x01\n\x0fOperationStatus\x12\x1e\n\x1aOPERATION_STATUS_UNDEFINED\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\x0b\n\x07\x46\x41ILURE\x10\x02\x12\x0b\n\x07TIMEOUT\x10\x03\x12\r\n\tNOT_FOUND\x10\x04\x12\x11\n\rNOT_SUPPORTED\x10\x05\x12\x0b\n\x07INVALID\x10\x06*u\n\x11\x44\x65viceControlType\x12\x1c\n\x18\x44\x45VICE_CONTROL_UNDEFINED\x10\x00\x12\x0c\n\x08\x45NERGIZE\x10\x01\x12\x0f\n\x0b\x44\x45_ENERGIZE\x10\x02\x12\x0b\n\x07RESTART\x10\x03\x12\x16\n\x12READ_SERIAL_NUMBER\x10\x04\x32\xd7\x03\n\rDeviceService\x12Y\n\rControlDevice\x12%.powerpay.device.DeviceControlRequest\x1a\x1f.powerpay.device.DeviceResponse\"\x00\x12`\n\x0fGetDeviceStatus\x12$.powerpay.device.DeviceStatusRequest\x1a%.powerpay.device.DeviceStatusResponse\"\x00\x12W\n\x0c\x43reateDevice\x12$.powerpay.device.CreateDeviceRequest\x1a\x1f.powerpay.device.DeviceResponse\"\x00\x12W\n\x0cUpdateDevice\x12$.powerpay.device.UpdateDeviceRequest\x1a\x1f.powerpay.device.DeviceResponse\"\x00\x12W\n\x0c\x44\x65leteDevice\x12$.powerpay.device.DeleteDeviceRequest\x1a\x1f.powerpay.device.DeviceResponse\"\x00\x42\x06Z\x04./pbb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'powerpay_protos.device_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\004./pb'
  _globals['_OPERATIONSTATUS']._serialized_start=1363
  _globals['_OPERATIONSTATUS']._serialized_end=1498
  _globals['_DEVICECONTROLTYPE']._serialized_start=1500
  _globals['_DEVICECONTROLTYPE']._serialized_end=1617
  _globals['_DEVICE']._serialized_start=183
  _globals['_DEVICE']._serialized_end=323
  _globals['_DEVICEREQUEST']._serialized_start=326
  _globals['_DEVICEREQUEST']._serialized_end=524
  _globals['_DEVICERESPONSE']._serialized_start=526
  _globals['_DEVICERESPONSE']._serialized_end=650
  _globals['_DEVICECONTROLCOMMAND']._serialized_start=652
  _globals['_DEVICECONTROLCOMMAND']._serialized_end=769
  _globals['_DEVICECONTROLREQUEST']._serialized_start=771
  _globals['_DEVICECONTROLREQUEST']._serialized_end=897
  _globals['_CREATEDEVICEREQUEST']._serialized_start=899
  _globals['_CREATEDEVICEREQUEST']._serialized_end=990
  _globals['_UPDATEDEVICEREQUEST']._serialized_start=992
  _globals['_UPDATEDEVICEREQUEST']._serialized_end=1061
  _globals['_DELETEDEVICEREQUEST']._serialized_start=1063
  _globals['_DELETEDEVICEREQUEST']._serialized_end=1132
  _globals['_DEVICESTATUSREQUEST']._serialized_start=1134
  _globals['_DEVICESTATUSREQUEST']._serialized_end=1203
  _globals['_DEVICESTATUSRESPONSE']._serialized_start=1206
  _globals['_DEVICESTATUSRESPONSE']._serialized_end=1360
  _globals['_DEVICESERVICE']._serialized_start=1620
  _globals['_DEVICESERVICE']._serialized_end=2091
# @@protoc_insertion_point(module_scope)



import datetime

from google.protobuf import timestamp_pb2 as _timestamp_pb2
from powerpay_protos import measurement_pb2 as _measurement_pb2
from powerpay_protos import device_pb2 as _device_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Telemetry(_message.Message):
    __slots__ = ("timestamp", "device", "measurement")
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    DEVICE_FIELD_NUMBER: _ClassVar[int]
    MEASUREMENT_FIELD_NUMBER: _ClassVar[int]
    timestamp: _timestamp_pb2.Timestamp
    device: _device_pb2.Device
    measurement: _containers.RepeatedCompositeFieldContainer[_measurement_pb2.Measurement]
    def __init__(self, timestamp: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., device: _Optional[_Union[_device_pb2.Device, _Mapping]] = ..., measurement: _Optional[_Iterable[_Union[_measurement_pb2.Measurement, _Mapping]]] = ...) -> None: ...
